@@ -3,7 +3,7 @@ package fa_code;
 ### OPEN SOURCE LICENSE - GNU AFFERO PUBLIC LICENSE Version 3.0 #######
 #
 #    Net::FullAuto - Powerful Network Process Automation Software
-#    Copyright (C) 2000-2014  Brian M. Kelly
+#    Copyright (C) 2000-2015  Brian M. Kelly
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as
@@ -70,19 +70,19 @@ if ($^O eq 'cygwin') {
 
 #####  SET EMAIL AUTOMATION SETTINGS  ########
 %email_addresses=(
-   'bkelly' => 'Brian.Kelly@fullautosoftware.net',
+   'bkelly' => 'Brian.Kelly@fullauto.com',
 );
 my $email_to=[
                ']USERNAME[',
-               'Brian.Kelly@fullautosoftware.net',
+               'Brian.Kelly@fullauto.com',
              ];
 #%email_defaults=(
 #   Usage       => 'notify_on_error',
 #   Mail_Method => 'smtp',
-#   Mail_Server => 'mailserver.fullautosoftware.net',
-#   Reply_To    => 'Brian.Kelly@fullautosoftware.net',
+#   Mail_Server => 'mailserver.fullauto.com',
+#   Reply_To    => 'Brian.Kelly@fullauto.com',
 #   To          => $email_to,
-#   From        => "$progname\@fullautosoftware.net"
+#   From        => "$progname\@fullauto.com"
 #);
 ##############################################
 
@@ -148,6 +148,12 @@ sub hello_world_old {
 
 }
 
+sub figlet_fonts {
+
+   Net::FullAuto::FA_Core::figlet();
+
+}
+
 sub menu_demo {
 
    my @list=`ls -1 /bin`;
@@ -161,7 +167,7 @@ sub menu_demo {
       },
 
       Select => 'Many',
-      Banner => "\n   Choose a /bin Utility :"
+      Banner => "\n   Choose a /bin Utility :\n\n"
    );
 
    my @selections=&Menu(\%Menu_1,$unattended);
@@ -199,7 +205,7 @@ sub howdy_world {
             "Line ",__LINE__,"\n";
       my %mail=(
          'To'      => [ 'Brian.Kelly@bcbsa.com' ],
-         'From'    => 'Brian.Kelly@fullautosoftware.net',
+         'From'    => 'Brian.Kelly@fullauto.com',
          'Body'    => "\nFullAuto ERROR =>\n\n".$stderr.
                       "       in fa_code.pm Line ".__LINE__,
          'Subject' => "FullAuto ERROR Encountered When Connecting to Ubuntu",
